@@ -167,15 +167,27 @@ boilerplate_conv(OPT,
                  );
 
 #ifdef HAVE_LUA_RECORDS
+
+bool g_luaRecordInsertWhitespace;
+
 string LUARecordContent::getCode() const
 {
   // in d_code, series of "part1" "part2"
   vector<string> parts;
   stringtok(parts, d_code, "\"");
   string ret;
-  for(const auto& p : parts) {
-    ret += p;
-    ret.append(1, ' ');
+  if (g_luaRecordInsertWhitespace) { // default before 5.0
+    for(const auto& part : parts) {
+      ret += part;
+      ret.append(1, ' ');
+    }
+  }
+  else { // default since 5.0
+    for(const auto& part : parts) {
+      if (part != " ") {
+        ret += part;
+      }
+    }
   }
   return ret;
 }
@@ -360,7 +372,7 @@ boilerplate_conv(SMIMEA,
                  conv.xfrHexBlob(d_cert, true);
                  )
 
-DSRecordContent::DSRecordContent() {}
+DSRecordContent::DSRecordContent() = default;
 boilerplate_conv(DS,
                  conv.xfr16BitInt(d_tag);
                  conv.xfr8BitInt(d_algorithm);
@@ -368,7 +380,7 @@ boilerplate_conv(DS,
                  conv.xfrHexBlob(d_digest, true); // keep reading across spaces
                  )
 
-CDSRecordContent::CDSRecordContent() {}
+CDSRecordContent::CDSRecordContent() = default;
 boilerplate_conv(CDS,
                  conv.xfr16BitInt(d_tag);
                  conv.xfr8BitInt(d_algorithm);
@@ -376,7 +388,7 @@ boilerplate_conv(CDS,
                  conv.xfrHexBlob(d_digest, true); // keep reading across spaces
                  )
 
-DLVRecordContent::DLVRecordContent() {}
+DLVRecordContent::DLVRecordContent() = default;
 boilerplate_conv(DLV,
                  conv.xfr16BitInt(d_tag);
                  conv.xfr8BitInt(d_algorithm);
@@ -403,7 +415,7 @@ boilerplate_conv(RRSIG,
                  conv.xfrBlob(d_signature);
                  )
 
-RRSIGRecordContent::RRSIGRecordContent() {}
+RRSIGRecordContent::RRSIGRecordContent() = default;
 
 boilerplate_conv(DNSKEY,
                  conv.xfr16BitInt(d_flags);
@@ -411,7 +423,7 @@ boilerplate_conv(DNSKEY,
                  conv.xfr8BitInt(d_algorithm);
                  conv.xfrBlob(d_key);
                  )
-DNSKEYRecordContent::DNSKEYRecordContent() {}
+DNSKEYRecordContent::DNSKEYRecordContent() = default;
 
 boilerplate_conv(CDNSKEY,
                  conv.xfr16BitInt(d_flags);
@@ -419,7 +431,7 @@ boilerplate_conv(CDNSKEY,
                  conv.xfr8BitInt(d_algorithm);
                  conv.xfrBlob(d_key);
                  )
-CDNSKEYRecordContent::CDNSKEYRecordContent() {}
+CDNSKEYRecordContent::CDNSKEYRecordContent() = default;
 
 boilerplate_conv(RKEY,
                  conv.xfr16BitInt(d_flags);
@@ -427,7 +439,7 @@ boilerplate_conv(RKEY,
                  conv.xfr8BitInt(d_algorithm);
                  conv.xfrBlob(d_key);
                  )
-RKEYRecordContent::RKEYRecordContent() {}
+RKEYRecordContent::RKEYRecordContent() = default;
 
 boilerplate_conv(NID,
                  conv.xfr16BitInt(d_preference);
